Attribute
=========

.. py:module:: moderngl
.. py:currentmodule:: moderngl

.. autoclass:: moderngl.Attribute

.. autoattribute:: Attribute.location
.. autoattribute:: Attribute.array_length
.. autoattribute:: Attribute.dimension
.. autoattribute:: Attribute.shape
.. autoattribute:: Attribute.name

.. toctree::
    :maxdepth: 2
